/* This file is part of The_Merry_Turnip
 * 
 * The_Merry_Turnip - TODO: Description
 * Copyright © DAVY Guillaume 2009 <davyg2@gmail.com>
 * 
 * The_Merry_Turnip is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * The_Merry_Turnip is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/*!	\file actionMesh.h
	\brief Definition of actionMesh class and its derivate class
	
	Contain actionMesh, observationMesh, prendreMesh, animateMesh definitions.
*/

#ifndef __ACTIONMESH_H_INCLUDED__
#define __ACTIONMESH_H_INCLUDED__

//! Enum all the actionMesh type
enum ACTION_TYPE
{
	//! The mesh has no action
	ACTION_AUCUNE=0,
	
	//! The mesh can be looked at
	ACTION_OBSERVER,
	
	//! The mesh can be taken
	ACTION_PRENDRE,
	
	//! The mesh can launch an animation
	ACTION_ANIMATE,
	
	//! The mesh is a perso you can speak to
	ACTION_PERSO
};



//! Class containing a mesh who can launched an action when it is clicked, derive from staticMesh
class actionMesh : public staticMesh
{
public:
	//! Constructor
	actionMesh(ACTION_TYPE=ACTION_AUCUNE);
	
	//! Destructor
	~actionMesh();
	
	//! Init the mesh
	virtual int init(int, IAnimatedMeshSceneNode *, int);
	
	//! Return the action type
	ACTION_TYPE getAction();
	
	//! Return actionMesh::combi
	int getCombi();
	
	//! Return Color
	SColor getColor();
private:
	//! Contain the action type
	ACTION_TYPE action;
	//! Contain the id of the item needed to combine
	int combi;
protected:
	//! Color of the ray who will point to the mesh
	SColor color;
};// End class actionMesh



//! Class containing a mesh who can be looked at, derive from actionMesh
class observationMesh : public actionMesh
{
public:
	//! Constructor
	observationMesh(ACTION_TYPE=ACTION_OBSERVER);
	
	//! Destructor
	~observationMesh();

	//! Init the mesh
	virtual int init(int, IAnimatedMeshSceneNode *, int);
	
private:
};// End class observationMesh



//! Class containing a mesh who can be taken, derive from observationMesh
class prendreMesh : public observationMesh
{
public:
	//! Constructor
	prendreMesh(ACTION_TYPE=ACTION_PRENDRE);
	
	//! Destructor
	~prendreMesh();

	//! Init the mesh
	virtual int init(int, IAnimatedMeshSceneNode *, int, int);

	//! Return the item id corresponding to the mesh
	int getItem();
private:
	//! Item id corresponding to the mesh
	int it;
};// End class prendreMesh



//! Class containing a mesh who can launched an animation, derive from observationMesh
class animateMesh : public observationMesh
{
public:
	//! Constructor
	animateMesh(ACTION_TYPE=ACTION_ANIMATE);
	
	//! Destructor
	~animateMesh();

	//! Init the mesh
	virtual int init(int, IAnimatedMeshSceneNode *, int, int, int, int);

	//! Return animateMesh::anim
	int getAnim();
	
	//! Return animateMesh::begin
	int getBegin();
	
	//! Return animateMesh::end
	int getEnd();
private:
	//! The mesh Id to anim
	int anim;
	//! The numeber of the frame where begin the animation
	int begin;
	//! The numeber of the frame where end the animation
	int end;
};// End class animateMesh


//! Class containing a mesh representing a person, what mean you can speak to it
class persoMesh : public observationMesh
{
public:
	persoMesh(ACTION_TYPE=ACTION_PERSO);
	~persoMesh();

	virtual int init(int, IAnimatedMeshSceneNode *, int, int);

	int getAnim();
	int getBegin();
	int getEnd();
private:
	int anim;
	int begin;
	int end;
};// End class persoMesh

#endif //__ACTIONMESH_H_INCLUDED__

