/* This file is part of The_Merry_Turnip
 * 
 * The_Merry_Turnip - TODO: Description
 * Copyright © DAVY Guillaume 2009 <davyg2@gmail.com>
 * 
 * The_Merry_Turnip is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * The_Merry_Turnip is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/*!	\file actionMesh.cpp
	\brief Implement actionMesh class and its derivate class
	
	Contain actionMesh, observationMesh, prendreMesh, animateMesh implementations.
*/

#include <game.h>

/*!
	\class actionMesh
	This class is most of the time use by child class and not directly.
	If combi=0, the action will be launched just by clicking instead it
	will wait to be combined with item of id actionMesh::combi.
	(A bit different for observation Mesh)
*/

/** Construct an actionMesh and set actionMesh::action to Action
	\param Action The action type */
actionMesh::actionMesh(ACTION_TYPE Action) : action(Action)
{
	color = SColor(255,255,255,255);
}

actionMesh::~actionMesh()
{
	
}

/** Call the staticMesh::init, and set actionMesh::combi to comb
	\param Id Id of mesh
	\param Node The pointer to the irrlicht mesh corresponding
	\param Combi Item to combine with
	\return staticMesh::init result */
int actionMesh::init(int Id,IAnimatedMeshSceneNode* Node, int Combi)
{
	combi = Combi;
	int r = staticMesh::init(Id,Node);
	//Why a <<8? : it's for the bitmask of the the getSceneNodeFromScreenCoordinatesBB
	getNode()->setID(getId()<<8);
	return r;
}

ACTION_TYPE actionMesh::getAction()
{
	return action;
}

int actionMesh::getCombi()
{
	return combi;
}

SColor actionMesh::getColor()
{
	return color;
}



/*!
	\class observationMesh
	It's really like an actionMesh, the only difference is that it can be looked at.
	The action of looking at should be launched when pressing mouse right button
*/

/** Construct an observationMesh and set actionMesh::actionMesh() with parameter Action
	\param Action The action type */
observationMesh::observationMesh(ACTION_TYPE Action) : actionMesh(Action)
{
	color = SColor(0,0,255,0);
}

observationMesh::~observationMesh()
{
	
}

/** Call the actionMesh::init
	\param Id Id of mesh
	\param Node The pointer to the irrlicht mesh corresponding
	\param Combi Item to combine with
	\return staticMesh::init result */
int observationMesh::init(int Id, IAnimatedMeshSceneNode* Node, int Combi)
{
	return actionMesh::init(Id,Node,Combi);
}



/*!
	\class prendreMesh
	This mesh is linked to the item of id prendreMesh::it, when action launched,
	the user should get the item.
	And since it's derive from an observationMesh it can be looked at too.
*/

/** Construct a prendreMesh and call observationMesh::observationMesh() with parameter Action
	\param act The action type */
prendreMesh::prendreMesh(ACTION_TYPE act) : observationMesh(act)
{
	color = SColor(255,255,0,0);
}

prendreMesh::~prendreMesh()
{
	
}

/** Call the actionMesh::init, set prendreMesh::it to ite
	\param Id Id of mesh
	\param Node The pointer to the irrlicht mesh corresponding
	\param Combi Item to combine with
	\param It Item associate to the mesh
	\return observationMesh::init result */
int prendreMesh::init(int Id, IAnimatedMeshSceneNode* Node, int Combi, int It)
{
	it=It;
	return observationMesh::init(Id,Node,Combi);
}

int prendreMesh::getItem()
{
	return it;
}



/*!
	\class animateMesh
	When the mesh is clicked the animation of mesh of id animateMesh::anim
	is laucnhed from animateMesh::begin to animateMesh::end.
	And since it's derive from an observationMesh it can be looked at too.
*/

/** Construct a prendreMesh and call observationMesh::observationMesh() with parameter Action
	\param act The action type */
animateMesh::animateMesh(ACTION_TYPE act) : observationMesh(act)
{
	color = SColor(255,0,0,255);
}

animateMesh::~animateMesh()
{
	
}

/** Call the actionMesh::init, set prendreMesh::it to ite
	\param Id Id of mesh
	\param Node The pointer to the irrlicht mesh corresponding
	\param Combi Item to combine with
	\param Anim Id of the mesh to animate
	\param Begin Number of the Frame where begin the animation
	\param End Number of the Frame where end the animation
	\return observationMesh::init result */
int animateMesh::init(int Id, IAnimatedMeshSceneNode* Node, int Combi, int Anim, int Begin, int End)
{
	anim=Anim;
	begin=Begin;
	end=End;
	return observationMesh::init(Id,Node,Combi);
}

int animateMesh::getAnim()
{
	return anim;
}

int animateMesh::getBegin()
{
	return begin;
}

int animateMesh::getEnd()
{
	return end;
}


//TODO
/*!
	\class persoMesh
	\todo Implement and make working this class
*/

