#include <game.h>

#include <iostream>

//! /todo Hide the fps when hide the console(or not)

//extern object main_namespace;

console::console() : base("console")
{
	text = new stringw(L"");
	
	history = new std::vector<stringw>;
	histPos=0;
}

console::~console()
{
	
}

int console::init(coeur *c,IGUIEnvironment *e)
{
	base::init(0,c);
	env = e;
	
	cons = env->addImage(rect<s32>(0,0,600,420));
	tx  = env->addEditBox(L"", rect<s32>(0, 20, 600, 400),true,cons);
	box = env->addEditBox(L"", rect<s32>(20, 400, 600, 420),true,cons);
	env->addStaticText(L">>>", rect<s32>(0, 400, 20, 420),false,true,cons);
	log("Console env init");

	tx->setEnabled(false);
	tx->setDrawBorder(false);
	tx->setWordWrap(true);
	tx->setMultiLine(true);
	tx->setAutoScroll(true);
	tx->setTextAlignment(EGUIA_UPPERLEFT, EGUIA_LOWERRIGHT);
	log("Tx configured");

	box->setDrawBorder(false);
	box->setMultiLine(false);
	log("Box configured");
	
	FPS = env->addStaticText(L"", rect<s32>(0,0,100,20),false,true,cons);
	
	cons->setVisible(false);
	
	mycore->py->addPyEnv("co",object(ptr(this)));
	mycore->py->addPyEnv("inter",object(ptr(c->in)));
	mycore->py->addPyEnv("mycredit",object(ptr(c->mycredit)));
	mycore->py->addPyEnv("currentChap",object(ptr(c->currentChap)));
	//mycore->py->addPyEnv("currentLieu",object(ptr(c->currentLieu)));
	mycore->py->addPyEnv("currentLocal",object(ptr(c->currentLocal)));
	
	mycore->py->exec("import sys");
	mycore->py->exec("out = sys.stdout");
	mycore->py->exec("err = sys.stderr");
	mycore->py->exec("sys.stdout = co");
	mycore->py->exec("sys.stderr = co");
	mycore->py->exec("def position():\n\tco.position()\n");
	mycore->py->exec("def rotation():\n\tco.rotation()\n");
	mycore->py->exec("def target():\n\tco.target()\n");
	mycore->py->exec("def exit():\n\tco.exit()\n");
	mycore->py->exec("def quit():\n\tco.quit()\n");
	mycore->py->exec("def help():\n\tco.help()\n");
	mycore->py->exec("def fps():\n\tco.fps()\n");
	
	return 1;
}

int console::update()
{
	if (cons->isVisible())
	{
		env->setFocus(box);
		FPS->setText((stringw(L"FPS : ") + stringw(env->getVideoDriver()->getFPS())).c_str());
	}
	else
		env->setFocus(0);
	return 1;
}

int console::close()
{
	mycore->py->exec("sys.stdout = out");
	mycore->py->exec("sys.stderr = err");
	base::close();
	return 1;
}

bool console::OnEvent(const SEvent& event)
{
	if ((event.EventType==EET_KEY_INPUT_EVENT)&&(event.KeyInput.PressedDown)&&(event.KeyInput.Key==KEY_TAB))
		exit();
	if ((event.EventType==EET_KEY_INPUT_EVENT)&&(event.KeyInput.PressedDown)&&(event.KeyInput.Key==KEY_UP)&&(histPos>0))
	{
		histPos--;
		box->setText(history->at(histPos).c_str());
	}
	if ((event.EventType==EET_KEY_INPUT_EVENT)&&(event.KeyInput.PressedDown)&&(event.KeyInput.Key==KEY_DOWN)&&(histPos<history->size()))
	{
			histPos++;
		if (histPos==history->size())
			box->setText(L"");
		else
			box->setText(history->at(histPos).c_str());
	}
	if (! cons->isVisible())
		return false;
	if ((event.EventType==EET_GUI_EVENT) && (event.GUIEvent.EventType==EGET_EDITBOX_ENTER))
	{
		write((stringc(">>>") + box->getText() + "\n").c_str());
		stringc msg = mycore->py->eval(box->getText());
		write(msg.c_str());
		history->push_back(box->getText());
		histPos=history->size();
		log(stringc("Run python command : ") + box->getText());
		box->setText(L"");
		return true;
	}
	if (cons->isVisible() && (event.EventType==EET_KEY_INPUT_EVENT))
		return true;
	return false;
}

/** This method log a text to the console, used by python to replace stdout
	\param message Text to log
	\return Nothing*/
void console::write(std::string const& message)
{
	*text = *text + (message.c_str());
	tx->setText(text->c_str());
	return;
}
	
void console::position()
{
	write((stringc("Camera position :\n\t") + stringc(mycore->cam->getPosition().X) + "\n\t" + stringc(mycore->cam->getPosition().Y) + "\n\t" + stringc(mycore->cam->getPosition().Z) + "\n").c_str());
	log("Display camera position");
}
	
void console::rotation()
{
	write((stringc("Camera rotation :\n\t") + stringc(mycore->cam->getRotation().X) + "\n\t" + stringc(mycore->cam->getRotation().Y) + "\n\t" + stringc(mycore->cam->getRotation().Z) + "\n").c_str());
	log("Display rotation");
}
	
void console::target()
{
	write((stringc("Camera target :\n\t") + stringc(mycore->cam->getTarget().X) + "\n\t" + stringc(mycore->cam->getTarget().Y) + "\n\t" + stringc(mycore->cam->getTarget().Z) + "\n").c_str());
	log("Display target position");
}

void console::exit()
{
	if (cons->isVisible())
	{
		cons->setVisible(false);
		log("Closing console");
	}
	else
	{
		cons->setVisible(true);
		log("Opening console");
	}
}

void console::quit()
{
	write("Quitting\n");
	mycore->q=true;
	log("Quitting by console");
}

void console::help()
{
	write("Welcome to the console of Merry Turnip\n");
	write((stringc("The version is ") + mycore->getVersion() + "\n").c_str());
	write("For the source code : 2009 (c) DAVY Guillaume\n");
	write("------------------------------------------------\n");
	write("Here is the list of avaidable command :\n");
	write("\t\thelp() : Show this message\n");
	write("\t\tposition() : give the position of the camera\n");
	write("\t\trotation() : give the rotation of the camera\n");
	write("\t\ttarget() : give the position of the target of the camera\n");
	write("\t\tfps() : give the fps\n");
	write("\t\texit() : exit the console\n");
	write("\t\tquit() : quit the game\n");
	write("------------------------------------------------\n");
	log("Show help");
}

void console::fps()
{
	write((stringc("FPS : ") + stringw(env->getVideoDriver()->getFPS()) + "\n").c_str());
	log("Show FPS");
}

