#include <game.h>

credit::credit() : base("credit"), activate(false), newY(0),y(0)
{
	logos = new std::vector<IGUIImage*>;
	texts = new std::vector<IGUIStaticText*>;
}

credit::~credit()
{
	delete texts;
	delete logos;
}

int credit::init(coeur *c,IGUIEnvironment *e,IXMLReader* xmlCredit)
{
	base::init(0,c);
	env = e;

	log(stringc("Credit xml loading ..."));
	
	activate=false;
	newY=c->getDim().Height + 40;
	y=0;
	while(xmlCredit && xmlCredit->read())
	{
		if (xmlCredit->getNodeType()==EXN_ELEMENT)
		{
			if (core::stringw("credit") == xmlCredit->getNodeName())
			{
				logos->reserve(xmlCredit->getAttributeValueAsInt(L"nbrlogo"));
				texts->reserve(xmlCredit->getAttributeValueAsInt(L"nbrtext"));
			}
			else if (core::stringw("logo") == xmlCredit->getNodeName())
			{
				addLogo(xmlCredit->getAttributeValue(L"path"));
				log( stringc("Add logo : \"") + xmlCredit->getAttributeValue(L"path") + "\"");
			}
			else if (core::stringw("text") == xmlCredit->getNodeName())
			{
				addText(xmlCredit->getAttributeValue(L"text"));
				log( stringc("Add text : \"") + xmlCredit->getAttributeValue(L"text") + "\"");
			}
			else if (core::stringw("sound") == xmlCredit->getNodeName())
			{
				sound = xmlCredit->getAttributeValue(L"path");
				log( stringc("Sound : \"") + xmlCredit->getAttributeValue(L"path") + "\"");
			}
		}
	}
	
	return 1;
}

int credit::update()
{
//TODO: Take care of time
//TODO: Cacher le curseur
	if (activate)
	{
		if (y++ >= newY)
			stop();
		if (y%1!=0)
			return 1;
		for (int i=logos->size()-1;i>-1;i--)
		{
			(*logos)[i]->setRelativePosition( logos->at(i)->getRelativePosition() - position2d<s32>(0,1) );
		}

		for (int i=texts->size()-1;i>-1;i--)
		{
			(*texts)[i]->setRelativePosition( texts->at(i)->getRelativePosition() - position2d<s32>(0,1) );
		}
	}
	return 1;
}

int credit::close()
{
	stop();

	log("Deleting logos");
	while (!logos->empty())
	{
		log("Deleting last logo");
		logos->pop_back();
	}

	log("Deleting texts");
	while (!texts->empty())
	{
		log("Deleting last text");
		texts->pop_back();
	}

	base::close();
	return 1;
}

int credit::start()
{
	activate = true;
	y=0;
	mycore->play(sound);
	log("Credit start");
	return 1;
}

int credit::stop()
{
	if (!activate)
		return 0;
	for (unsigned int i=0;i<logos->size();i++)
	{
		(*logos)[i]->setRelativePosition( logos->at(i)->getRelativePosition() + position2d<s32>(0,y) );
	}

	for (unsigned int i=0;i<texts->size();i++)
	{
		(*texts)[i]->setRelativePosition( texts->at(i)->getRelativePosition() + position2d<s32>(0,y) );
	}
	activate = false;
	log("Credit stop");
	return 1;
}

int credit::addLogo(stringc path)
{
	if (activate)
		return 0;
	IGUIImage* img = env->addImage( mycore->getTexture( path.c_str() ), position2d<s32>(0,newY) );
	rect<s32> dim = img->getRelativePosition();
	int w = dim.getWidth();
	dim.UpperLeftCorner = position2d<s32>( (mycore->getDim().Width - w)/2 , newY);
	dim.LowerRightCorner = position2d<s32>( (mycore->getDim().Width + w)/2 , dim.LowerRightCorner.Y);
	img->setRelativePosition(dim);
	logos->push_back(img);
	newY += 50;
	log("Image added");
	return 1;
}

int credit::addText(stringw text)
{
	if (activate)
		return 0;
	IGUIStaticText* txt = env->addStaticText( text.c_str(), rect<s32>(200,newY,mycore->getDim().Width-200,newY+20) );
	txt->setTextAlignment(EGUIA_CENTER,EGUIA_CENTER);
	texts->push_back(txt);
	newY += 20;
	log("Text added");
	return 1;
}


bool credit::OnEvent(const SEvent& event)
{
	return false;
}

