/* This file is part of The_Merry_Turnip
 * 
 * The_Merry_Turnip - TODO: Description
 * Copyright © DAVY Guillaume 2009 <davyg2@gmail.com>
 * 
 * The_Merry_Turnip is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * The_Merry_Turnip is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/*!	\file modPyMerry.cpp
	\brief Create the python module who wrap the game
	
	\todo Ajouter des repr à tous les objets pour une intégration plus belle avec python cf class_<item>
*/

#include <game.h>

BOOST_PYTHON_MODULE(pyMerry)
{
	class_<item>("item")
		.def("init", &item::init)
		.def("getId", &item::getId)
		.def("getTexture", &item::getTexture)
		.def("getCombi", &item::getCombi)
		.def("getCombiResult", &item::getCombiResult)
		.def("__repr__", &item::repr)
	;
	
	//! Problem with pure virtual function OnEvent
	/*class_<base>("base")
		.def("getId",&base::getId)
		.def("log",&base::log)
		.def("isInit",&base::isInit)
	;*/
	
	class_<staticMesh>("staticMesh")
		.def("getId", &staticMesh::getId)
		.def("setVisible", &staticMesh::setVisible)
	;
	
	enum_<ACTION_TYPE>("ACTION_TYPE")
		.value("ACTION_AUCUNE", ACTION_AUCUNE)
		.value("ACTION_OBSERVER", ACTION_OBSERVER)
		.value("ACTION_PRENDRE", ACTION_PRENDRE)
		.value("ACTION_ANIMATE", ACTION_ANIMATE)
		.value("ACTION_PERSO", ACTION_PERSO)
	;
	
	class_<actionMesh,bases<staticMesh> >("actionMesh")
		.def("getAction", &actionMesh::getAction)
		.def("getCombi", &actionMesh::getCombi)
	;
	
	class_<observationMesh,bases<actionMesh> >("observationMesh")
	;
	
	class_<prendreMesh,bases<observationMesh> >("prendreMesh")
		.def("getItem", &prendreMesh::getItem)
	;
	
	class_<animateMesh,bases<observationMesh> >("animateMesh")
		.def("getAnim", &animateMesh::getAnim)
		.def("getBegin", &animateMesh::getBegin)
		.def("getEnd", &animateMesh::getEnd)
	;
	
	class_<localItem>("localItem")
		.def("init",&localItem::init)
		.def("getId",&localItem::getId)
		.def("getText",&localItem::getText)
		.def("getPath",&localItem::getPath)
	;
	
	class_<chap>("chap")
		.def("addItem",&chap::addItem)
		.def("getItemFromId",&chap::getItemFromId)
	;
	
	class_<credit>("credit")
		.def("start",&credit::start)
		.def("stop",&credit::stop)
		.def("addLogo",&credit::addLogo)
		.def("addText",&credit::addText)
	;
	
	class_<local>("local")
		.def("getObservationMesh",&local::getObservationMesh, return_internal_reference<1>())
		.def("getObservationItem",&local::getObservationItem, return_internal_reference<1>())
		.def("getCombinaison",&local::getCombinaison, return_internal_reference<1>())
		.def("getCaption",&local::getCaption)
	;
	
	class_<interface>("interface")
		.def("setImage",&interface::setImage)
		.def("afficherInventaire",&interface::afficherInventaire)
		.def("setImagePosition",&interface::setImagePosition)
		.def("addItemInventaire",&interface::addItemInventaire)
		//.def("addInventaire",&interface::addInventaire)
		//.def("getInventaire",&interface::getInventaire, return_internal_reference<1>())
	;
	
	class_<coeur/*,bases<base>*/>("coeur")
		.def("getTime", &coeur::getTime)
		.def("setCaption", &coeur::setCaption)
		//.def("addMesh", &coeur::addMesh, return_value_policy<manage_new_object>() )
		//.def("loadTexture", (int (coeur::*)(irr::core::stringc)) &coeur::loadTexture)
		.def("getDim", &coeur::getDim)
		.def("getSelectedAction", &coeur::getSelectedAction, return_internal_reference<1>())
		.def("getItem", &coeur::getItem)
		.def("getActionMesh", (actionMesh * (coeur::*)(int)) &coeur::getActionMesh, return_internal_reference<1>())
		.def("getObservationMesh", &coeur::getObservationMesh, return_internal_reference<1>())
		.def("getObservationItem", &coeur::getObservationItem, return_internal_reference<1>())
		.def("getCombinaison", &coeur::getCombinaison, return_internal_reference<1>())
		.def("getVersion", &coeur::getVersion)
		.def("play", &coeur::play)
		//.def("getLogger", &coeur::getLogger)
		.def("startCredit", &coeur::startCredit)
		.def("loadChap", &coeur::loadChap)
		.def("loadLieu", &coeur::loadChap)
		.def("loadLocal", &coeur::loadChap)
	;
	
	class_<console>("console")
		.def("write", &console::write)
		.def("position", &console::position)
		.def("rotation", &console::rotation)
		.def("target", &console::target)
		.def("exit", &console::exit)
		.def("quit", &console::quit)
		.def("help", &console::help)
		.def("fps", &console::fps)
	;
}

